@@ -1,5 +1,5 @@
 require 'aruba/api/environment'
-require 'aruba/api/command'
+require 'aruba/api/commands'
 
 # Aruba
 module Aruba
@@ -16,7 +16,7 @@ module Aruba
       # @param [String] gemset
       #   The name of the gemset to be used
       def use_clean_gemset(gemset)
-        run_simple(%{rvm gemset create "#{gemset}"}, true)
+        run_command_and_stop(%{rvm gemset create "#{gemset}"}, true)
         if all_stdout =~ /'#{gemset}' gemset created \((.*)\)\./
           gem_home = Regexp.last_match[1]
           set_environment_variable('GEM_HOME', gem_home)
@@ -27,18 +27,11 @@ module Aruba
           paths.unshift(File.join(gem_home, 'bin'))
           set_environment_variable('PATH', paths.uniq.join(File::PATH_SEPARATOR))
 
-          run_simple("gem install bundler", true)
+          run_command_and_stop("gem install bundler", true)
         else
           raise "I didn't understand rvm's output: #{all_stdout}"
         end
       end
-
-      # Unset variables used by bundler
-      def unset_bundler_env_vars
-        %w[RUBYOPT BUNDLE_PATH BUNDLE_BIN_PATH BUNDLE_GEMFILE].each do |key|
-          set_environment_variable(key, nil)
-        end
-      end
     end
   end
 end
