@@ -18,6 +18,3 @@ else
   Dir.glob(::File.expand_path('../support/*.rb', __FILE__)).each { |f| require_relative f }
   Dir.glob(::File.expand_path('../support/**/*.rb', __FILE__)).each { |f| require_relative f }
 end
-
-# Avoid writing "describe LocalPac::MyClass do [..]" but "describe MyClass do [..]"
-include Aruba
